@@ -53,7 +53,7 @@
 
 airnow_createMonitorObjects <- function(
   parameters = NULL,
-  startdate = strftime(lubridate::now(), "%Y%m%d", tz = "UTC"),
+  startdate = strftime(lubridate::now(tzone = "UTC"), "%Y%m%d", tz = "UTC"),
   hours = 24,
   zeroMinimum = TRUE,
   addGoogleMeta = TRUE
