@@ -43,15 +43,17 @@ airsis_qualityControl <- function(
 
   logger.debug(" ----- airsis_qualityControl() ----- ")
 
+  # ----- Validate parameters --------------------------------------------------
+
   # Sanity check -- row count
   if ( nrow(tbl) == 0 ) {
-    logger.error("Unable to perform QC: tibble empty")
-    stop(paste0("Unable to perform QC: tibble empty"))
+    logger.warn("No valid PM2.5 data") # This is more of a warning than some error in the data.
+    stop("No valid PM2.5 data")
   }
 
   # Sanity check -- tbl must have a monitorType
   if ( !'monitorType' %in% names(tbl) ) {
-    logger.error("No 'monitorType' column found in 'tbl' tibble with columns: %s", paste0(names(tbl), collapse=", "))
+    logger.error("No 'monitorType' column found in 'tbl' tibble with columns: %s", paste0(names(tbl), collapse = ", "))
     stop(paste0("No 'monitorType' column found in 'tbl' tibble."))
   }
 
@@ -59,13 +61,25 @@ airsis_qualityControl <- function(
 
   # Sanity check -- tbl must have only one monitorType
   if ( length(monitorType) > 1 ) {
-    logger.error("Multilpe monitor types found in 'tbl' tibble: %s", paste0(monitorType, collapse=", "))
+    logger.error("Multilpe monitor types found in 'tbl' tibble: %s", paste0(monitorType, collapse = ", "))
     stop(paste0("Multiple monitor types found in 'tbl' tibble."))
   }
 
   monitorType <- monitorType[1]
 
-  logger.trace("Applying %s QC rules", monitorType)
+  monitorSubtype <- unique(tbl$monitorSubtype)
+
+  # Sanity check -- tbl must have only one monitorSubtype
+  if ( length(monitorSubtype) > 1 ) {
+    logger.error("Multilpe monitor sybtypes found in 'tbl' tibble: %s", paste0(monitorSubtype, collapse = ", "))
+    stop(paste0("Multiple monitor subtypes found in 'tbl' tibble."))
+  }
+
+  monitorSubtype <- monitorSubtype[1]
+
+  # ----- Apply type-specific QC -----------------------------------------------
+
+  logger.trace("Applying %s %s QC rules", monitorType, monitorSubtype)
 
   if ( monitorType == 'BAM1020' ) {
 
@@ -73,11 +87,21 @@ airsis_qualityControl <- function(
 
   } else if ( monitorType == 'EBAM' ) {
 
-    tbl <- airsis_EBAMQualityControl(tbl, ...)
+    if ( monitorSubtype == "MULTI2" ) {
+      tbl <- airsis_EBAM_MULTI2QualityControl(tbl, ...)
+    } else if ( monitorSubtype == "PLUS_MULTI" ) {
+      tbl <- airsis_EBAM_PLUS_MULTIQualityControl(tbl, ...)
+    } else {
+      tbl <- airsis_EBAMQualityControl(tbl, ...)
+    }
 
   } else if ( monitorType == 'ESAM' ) {
 
-    tbl <- airsis_ESAMQualityControl(tbl, ...)
+    if ( monitorSubtype == "MULTI" ) {
+      tbl <- airsis_ESAM_MULTIQualityControl(tbl, ...)
+    } else {
+      tbl <- airsis_ESAMQualityControl(tbl, ...)
+    }
 
   } else {
 
