@@ -40,7 +40,9 @@
 #' @references https://forum.airnowtech.org/t/how-does-airnow-handle-negative-hourly-concentrations/143
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
+#' library(PWFSLSmoke)
+#'
 #' N_M <- monitor_subset(Northwest_Megafires, tlim=c(20150815,20150831))
 #' Omak <- monitor_subset(N_M, monitorIDs='530470013_01')
 #' Omak_nowcast <- monitor_nowcast(Omak, includeShortTerm=TRUE)
@@ -76,9 +78,11 @@
 # 5. Compute the NowCast by summing these products and dividing by the sum of the weight factors raised to the power of
 #    how many hours ago the concentration was measured.
 
-monitor_nowcast <- function(ws_monitor,
-                            version='pm',
-                            includeShortTerm=FALSE) {
+monitor_nowcast <- function(
+  ws_monitor,
+  version = 'pm',
+  includeShortTerm = FALSE
+) {
 
   # Sanity check
   if ( monitor_isEmpty(ws_monitor) ) stop("ws_monitor object contains zero monitors")
