@@ -24,17 +24,22 @@
 #' @note This function wraps the \link{monitor_print} function but defaults
 #' to \code{quietly = FALSE}.
 #' @examples
+#' library(PWFSLSmoke)
+#'
 #' data("Carmel_Valley")
 #' Carmel_Valley <- monitor_subset(Carmel_Valley, tlim = c(20160802,20160803))
+#'
 #' monitor_print(Carmel_Valley)
 #' monitor_print(Carmel_Valley, metaOnly = TRUE)
 #' monitor_print(Carmel_Valley, dataOnly = TRUE)
 
-monitor_writeCSV <- function(ws_monitor,
-                             saveFile = NULL,
-                             metaOnly = FALSE,
-                             dataOnly = FALSE,
-                             quietly = TRUE) {
+monitor_writeCSV <- function(
+  ws_monitor,
+  saveFile = NULL,
+  metaOnly = FALSE,
+  dataOnly = FALSE,
+  quietly = TRUE
+) {
 
   # Sanity check
   if ( monitor_isEmpty(ws_monitor) )
