@@ -52,14 +52,14 @@ rawPlot_timeseries <- function(df,
                                hourLwd=0,
                                hourInterval=6,
                                ...) {
-  
+
   # ----- Initial coherency checks -------------
-  
+
   # Verify plot parameter exists
   if ( !(parameter %in% names(df)) ) {
     stop(paste0("'",parameter,"' does not exist in names(",deparse(substitute(df)),")",sep=""))
   }
-  
+
   # Verify shadedBackground parameter exists
   if ( !(is.null(shadedBackground)) ) {
     if ( !(shadedBackground %in% names(df)) ) {
@@ -67,12 +67,12 @@ rawPlot_timeseries <- function(df,
       shadedBackground <- NULL
     }
   }
-  
+
   # ----- Data Preparation ----------------------------------------------------
-  
+
   # Identify timezone(s)
   timezone <- unique(df$timezone)
-  
+
   # Force timezone to UTC and disable shadedNight if >1 timezone in metadata for monitorIDs
   if ( length(timezone)>1 ) { # note that we will only enter this condition if localTime==TRUE
     if ( localTime ) {
@@ -82,22 +82,22 @@ rawPlot_timeseries <- function(df,
     if ( shadedNight ) {
       warning(">1 timezone in metadata for selected monitorIDs: Shaded Night disabled")
       shadedNight <- FALSE
-    }    
+    }
   }
-  
+
   # Set timezone to UTC if localTime==FALSE
   if ( !localTime ) {
     timezone <- "UTC"
   }
-  
+
   # Set time axis data
   df$datetime <- lubridate::with_tz(df$datetime, tzone=timezone)
-  
+
   # Time limit application
   # TODO: add logic to check for tlim format
   # TODO: warn if tlim is outside range of datetime data
   if ( !is.null(tlim) ) {
-    
+
     # When tlim is specified in whole days we add hours to get the requsted full days
     tlimStrings <- as.character(tlim)
     if ( stringr::str_length(tlimStrings)[1] == 8 ) {
@@ -106,8 +106,8 @@ rawPlot_timeseries <- function(df,
     if ( stringr::str_length(tlimStrings)[2] == 8 ) {
       tlim[2] <- paste0(tlim[2],'23')
     }
-    tlim <- PWFSLSmoke::parseDatetime(tlim, timezone=timezone)
-    
+    tlim <- MazamaCoreUtils::parseDatetime(tlim, timezone = timezone)
+
     # Create time mask and subset data
     timeMask <- df$datetime >= tlim[1] & df$datetime <= tlim[2]
     if ( sum(timeMask)==0 ) {
@@ -115,34 +115,34 @@ rawPlot_timeseries <- function(df,
     }
     df <- df[timeMask,]
   }
-  
+
   # Pull out key data
   times <- df$datetime
   data <- df[[parameter]]
-  
+
   # Cap hour interval
   if ( hourInterval>12 ) {
     warning("Hour interval capped at 12 hours")
     hourInterval <- min(hourInterval,12)
   }
-  
+
   # ----- Style / Argument List -----------------------------------------------
-  
+
   argsList <- list(...) #TODO: add ... in parens when finished...
-  
+
   # Prep the data to plot, based on parameter selection by user (default = "pm25")
   argsList$x <- times
   argsList$y <- data
-  
+
   # xlab
-  if ( !('xlab' %in% names(argsList)) ) {  
+  if ( !('xlab' %in% names(argsList)) ) {
     if ( timezone=="UTC" ) {
       argsList$xlab <- "Date and Time (UTC)"
     } else {
       argsList$xlab <- "Date and Time (local)"
     }
   }
-  
+
   # ylab
   if ( !('ylab' %in% names(argsList)) ) {
     if (parameter == "temperature") {
@@ -161,7 +161,7 @@ rawPlot_timeseries <- function(df,
       argsList$ylab <- parameter
     }
   }
-  
+
   # main (Title)
   if ( !('main' %in% names(argsList)) ) {
     if (parameter == "temperature") {
@@ -180,7 +180,7 @@ rawPlot_timeseries <- function(df,
       argsList$main <- parameter
     }
   }
-  
+
   # type
   if ( !('type' %in% names(argsList)) ) {
     if ( parameter== "windDir" ) {
@@ -189,26 +189,26 @@ rawPlot_timeseries <- function(df,
       argsList$type <- "l"
     }
   }
-  
+
   # ylim TODO: better ylim smarts
   if ( !('ylim' %in% names(argsList)) ) {
     argsList$ylim <- max(c(data,0), na.rm=TRUE)
     argsList$ylim <- c(0, argsList$ylim*1.1)
   }
-  
+
   # ----- Plotting ------------------------------------------------------------
-  
+
   if ( !add ) {
-    
+
     # Set up argsList for blank plot...review to ensure everything captured
     argsListBlank <- argsList
-    
+
     argsListBlank$col <- 'transparent'
     argsListBlank$axes <- FALSE
-    
+
     # Create blank plot canvas
     do.call(plot,argsListBlank)
-    
+
     # Shaded Night
     # Based on first deployment lat/lon if >1 deployment; breaks if >1 time zone
     if ( shadedNight ) {
@@ -222,7 +222,7 @@ rawPlot_timeseries <- function(df,
         addShadedNight(timeInfo)
       }
     }
-    
+
     # Add vertical lines to denote days and/or hour breaks
     hour_indices <- which(as.numeric(strftime(times,format="%H",tz=timezone)) %% hourInterval == 0)
     day_indices <- which(as.numeric(strftime(times,format="%H",tz=timezone)) %% 24 == 0)
@@ -233,33 +233,33 @@ rawPlot_timeseries <- function(df,
     if ( dayLwd > 0 ) {
       abline(v=times[day_indices], lwd=dayLwd) # at beginning of day
     }
-    
+
     # Add horizontal grid lines (before points if grid=='under')
     if ( gridPos == 'under' && gridLwd > 0 ) {
       abline(h=axTicks(2)[-1], col=gridCol, lwd=gridLwd, lty=gridLty)
     }
-    
+
     # Put a box around the plot area
     box()
-    
+
     # Add axes if we are not adding points on top of an existing plot
     axis(2, las=1)
     axis.POSIXct(1, times) # TODO: better x axis smarts, e.g. keep from saying "Monday, Tuesday" etc...
-    
+
     # Shaded background
     if ( !is.null(shadedBackground) ) {
       dataSB <- df[[shadedBackground]]
       PWFSLSmoke::addShadedBackground(param=dataSB, timeAxis=times, lwd=sbLwd)
     }
-    
+
   }
-  
+
   # Add lines
   do.call(lines,argsList)
-  
+
   if ( gridPos == 'over' && gridLwd > 0 ) {
     # Horizontal lines
     abline(h=axTicks(2)[-1], col=gridCol, lwd=gridLwd, lty=gridLty)
   }
-  
+
 }
