@@ -19,12 +19,12 @@ rawPlot_windRose <- function(df,
                              tlim=NULL,
                              localTime=TRUE,
                              ...) {
-  
+
   # ----- Data Preparation -----------------
-  
+
   # Identify timezone(s)
   timezone <- unique(df$timezone)
-  
+
   # Force timezone to UTC if >1 timezone in metadata for monitorIDs
   if ( length(timezone) > 1 ) { # note that we will only enter this condition if localTime==TRUE
     if ( localTime ) {
@@ -32,15 +32,15 @@ rawPlot_windRose <- function(df,
       timezone <- "UTC"
     }
   }
-  
+
   # Set timezone to UTC if localTime==FALSE
   if ( !localTime ) {
     timezone <- "UTC"
   }
-  
+
   # Set time axis data
   df$datetime <- lubridate::with_tz(df$datetime, tzone=timezone)
-  
+
   # Time limit application
   # TODO: add logic to check for tlim format
   # TODO: warn if tlim is outside range of datetime data
@@ -53,8 +53,8 @@ rawPlot_windRose <- function(df,
     if ( stringr::str_length(tlimStrings)[2] == 8 ) {
       tlim[2] <- paste0(tlim[2],'23')
     }
-    tlim <- PWFSLSmoke::parseDatetime(tlim, timezone=timezone)
-    
+    tlim <- MazamaCoreUtils::parseDatetime(tlim, timezone = timezone)
+
     # Create time mask and subset data
     timeMask <- df$datetime >= tlim[1] & df$datetime <= tlim[2]
     if ( sum(timeMask)==0 ) {
@@ -62,7 +62,7 @@ rawPlot_windRose <- function(df,
     }
     df <- df[timeMask,]
   }
-  
+
   # Populate arguments for openair::windRose
   argsList <- list(...)
   argsList$mydata <- df
@@ -78,10 +78,10 @@ rawPlot_windRose <- function(df,
   if ( !('paddle' %in% names(argsList)) ) {
     argsList$paddle <- FALSE
   }
-  
+
   # ----- Plotting -------------------------
-  
+
   # Create Plot
   do.call(openair::windRose,argsList)
-  
+
 }
