@@ -26,11 +26,15 @@
 #' title(paste0('Area Under Curve = ', format(auc,digits = 3)))
 #' }
 
-skill_ROC <- function(predicted,
-                      observed,
-                      t1Range = NULL,
-                      t2 = NULL,
-                      n = 101) {
+skill_ROC <- function(
+  predicted,
+  observed,
+  t1Range = NULL,
+  t2 = NULL,
+  n = 101
+) {
+
+  # ----- Validate parameters --------------------------------------------------
 
   # Extract data from ws_monitor objects
   if ( 'ws_monitor' %in% class(predicted) ) {
@@ -67,6 +71,8 @@ skill_ROC <- function(predicted,
     stop(paste0("observed must be a number vector"))
   }
 
+  # ----- Prepare variables ----------------------------------------------------
+
   # Remove any elements where either predicted or observed has NA
   m <- matrix(c(predicted, observed), ncol = 2)
   badRows <- apply(m, 1, function(x) { any(is.na(x)) })
@@ -86,7 +92,7 @@ skill_ROC <- function(predicted,
   # Calculate ROC and cost
   roc <- data.frame(threshold = testThresholds, FPR = NA, TPR = NA, cost = NA)
   for ( i in seq_along(testThresholds) ) {
-    cm <- skill_confusionMatrix(predicted >= testThresholds[i], observed >= t2, lightweight = TRUE)
+    cm <- skill_confusionMatrix(predicted >= testThresholds[i], observed >= t2)
     roc$FPR[i] <- cm$FPRate
     roc$TPR[i] <- cm$TPRate
     roc$cost[i] <- cm$cost
@@ -105,5 +111,16 @@ skill_ROC <- function(predicted,
   roc <- roc[with(roc, order(threshold)),]
   return(list(roc = roc, auc = auc))
 
+  if ( FALSE ) {
+    ca <- airnow_loadAnnual(2017) %>%
+      monitor_subset(tlim = c(20171001,20171101), stateCodes = 'CA')
+    Vallejo <- predicted <- monitor_subset(ca, monitorIDs = '060950004_01')
+    Napa <- observed <- monitor_subset(ca, monitorIDs = '060550003_01')
+    t2 <- AQI$breaks_24[4] # 'Unhealthy'
+    t1Range <-  c(55.5,55.5)
+    skill_ROC(Vallejo, Napa,t2 = t2)
+    skill_ROCPlot(Vallejo, Napa, t2 = t2)
+  }
+
 }
 
