@@ -30,7 +30,10 @@
 #'
 #' @examples
 #' \dontrun{
+#' library(PWFSLSmoke)
+#'
 #' tbl <- wrcc_createRawDataframe(20150701, 20150930, unitID = 'SM16')
+#' dplyr::glimpse(tbl)
 #' }
 #'
 #' @note The downloaded CSV may be saved to a local file by providing an argument to the \code{saveFile} parameter.
@@ -44,8 +47,8 @@
 #' @references \href{https://wrcc.dri.edu/cgi-bin/smoke.pl}{Fire Cache Smoke Monitoring Archive}
 
 wrcc_createRawDataframe <- function(
-  startdate = strftime(lubridate::now(),"%Y010100",tz = "UTC"),
-  enddate = strftime(lubridate::now(),"%Y%m%d23",tz = "UTC"),
+  startdate = strftime(lubridate::now(tzone = "UTC"),"%Y010100",tz = "UTC"),
+  enddate = strftime(lubridate::now(tzone = "UTC"),"%Y%m%d23",tz = "UTC"),
   unitID = NULL,
   clusterDiameter = 1000,
   baseUrl = "https://wrcc.dri.edu/cgi-bin/wea_list2.pl",
